Permissions
-----------

.. automodule:: django_ram.rest_framework.permissions
    :members:
    :undoc-members:
    :exclude-members: generate_permission_name_from_role_definition       
    :show-inheritance:
